==> huaweicloudsdkdws-3.1.119-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/list_audit_log_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAuditLogResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'records': 'list[AuditDumpRecord]',
        'cluster_id': 'str',
        'count': 'int'
    }

    attribute_map = {
        'records': 'records',
        'cluster_id': 'cluster_id',
        'count': 'count'
    }

    def __init__(self, records=None, cluster_id=None, count=None):
        """ListAuditLogResponse

        The model defined in huaweicloud sdk

        :param records: 审计日志列表。
        :type records: list[:class:`huaweicloudsdkdws.v2.AuditDumpRecord`]
        :param cluster_id: 集群ID。
        :type cluster_id: str
        :param count: 总数。
        :type count: int
        """
        
        super(ListAuditLogResponse, self).__init__()

        self._records = None
        self._cluster_id = None
        self._count = None
        self.discriminator = None

        if records is not None:
            self.records = records
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if count is not None:
            self.count = count

    @property
    def records(self):
        """Gets the records of this ListAuditLogResponse.

        审计日志列表。

        :return: The records of this ListAuditLogResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.AuditDumpRecord`]
        """
        return self._records

    @records.setter
    def records(self, records):
        """Sets the records of this ListAuditLogResponse.

        审计日志列表。

        :param records: The records of this ListAuditLogResponse.
        :type records: list[:class:`huaweicloudsdkdws.v2.AuditDumpRecord`]
        """
        self._records = records

    @property
    def cluster_id(self):
        """Gets the cluster_id of this ListAuditLogResponse.

        集群ID。

        :return: The cluster_id of this ListAuditLogResponse.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this ListAuditLogResponse.

        集群ID。

        :param cluster_id: The cluster_id of this ListAuditLogResponse.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def count(self):
        """Gets the count of this ListAuditLogResponse.

        总数。

        :return: The count of this ListAuditLogResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListAuditLogResponse.

        总数。

        :param count: The count of this ListAuditLogResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAuditLogResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdws-3.1.148-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/list_audit_log_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAuditLogResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'records': 'list[AuditDumpRecord]',
        'cluster_id': 'str',
        'count': 'int'
    }

    attribute_map = {
        'records': 'records',
        'cluster_id': 'cluster_id',
        'count': 'count'
    }

    def __init__(self, records=None, cluster_id=None, count=None):
        r"""ListAuditLogResponse

        The model defined in huaweicloud sdk

        :param records: 审计日志列表。
        :type records: list[:class:`huaweicloudsdkdws.v2.AuditDumpRecord`]
        :param cluster_id: 集群ID。
        :type cluster_id: str
        :param count: 总数。
        :type count: int
        """
        
        super(ListAuditLogResponse, self).__init__()

        self._records = None
        self._cluster_id = None
        self._count = None
        self.discriminator = None

        if records is not None:
            self.records = records
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if count is not None:
            self.count = count

    @property
    def records(self):
        r"""Gets the records of this ListAuditLogResponse.

        审计日志列表。

        :return: The records of this ListAuditLogResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.AuditDumpRecord`]
        """
        return self._records

    @records.setter
    def records(self, records):
        r"""Sets the records of this ListAuditLogResponse.

        审计日志列表。

        :param records: The records of this ListAuditLogResponse.
        :type records: list[:class:`huaweicloudsdkdws.v2.AuditDumpRecord`]
        """
        self._records = records

    @property
    def cluster_id(self):
        r"""Gets the cluster_id of this ListAuditLogResponse.

        集群ID。

        :return: The cluster_id of this ListAuditLogResponse.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        r"""Sets the cluster_id of this ListAuditLogResponse.

        集群ID。

        :param cluster_id: The cluster_id of this ListAuditLogResponse.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def count(self):
        r"""Gets the count of this ListAuditLogResponse.

        总数。

        :return: The count of this ListAuditLogResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ListAuditLogResponse.

        总数。

        :param count: The count of this ListAuditLogResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAuditLogResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
